@@ -14,6 +14,7 @@ from .base import (
     FilterStep,
     ConditionalStep,
     ClearFileObjectStep,
+    TimeStreamPathRenameStep
 )
 from .audit import (
     ImageMeanColourStep,
@@ -37,6 +38,11 @@ from .roitracker import (
 )
 from .verify import UnsafeNuker
 
+from .influxdb import InfluxClientRecordStep
+
+from .phenocam import PhenocamRGBMetricStep
+
+from .backblaze import WriteToB2Step
 
 __all__ = [
     "ResultRecorder",
@@ -48,6 +54,7 @@ __all__ = [
     "FilterStep",
     "ConditionalStep",
     "ClearFileObjectStep",
+    "TimeStreamPathRenameStep",
     "ImageMeanColourStep",
     "ScanQRCodesStep",
     "CalculateEVStep",
@@ -61,4 +68,7 @@ __all__ = [
     "UnsafeNuker",
     "ROIMaskManager",
     "ROIPipelineStep",
+    "PhenocamRGBMetricStep",
+    "InfluxClientRecordStep",
+    "WriteToB2Step"
 ]
