@@ -4,20 +4,14 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import copy
-import datetime as dt
 import hashlib
 import io
 import os
 import os.path as op
 import json
 from pathlib import Path
-from queue import Queue
-import re
-from sys import stderr, stdout, stdin
 import tarfile
-from threading import Thread
 import traceback
-import warnings
 import zipfile
 import zlib
 
@@ -809,6 +803,9 @@ class InMemoryTimeStream(TimeStream):
     def from_fofn(self):
         raise NotImplementedError("from_fofn is not implemented in InMemoryTimestream")
 
+    def __del__(self):
+        del self._images
+
     @property
     def instants(self):
         return [f.instant for f in self._images]
